@@ -52,6 +52,7 @@ static gboolean m_show_sound_level = FALSE;
 static gboolean m_hotkey_up_enabled = FALSE;
 static gboolean m_hotkey_down_enabled = FALSE;
 static gboolean m_hotkey_mute_enabled = FALSE;
+static gboolean m_use_transparent_background = FALSE;
 
 //##############################################################################
 // Static functions
@@ -59,7 +60,7 @@ static gboolean m_hotkey_mute_enabled = FALSE;
 static void config_load_default()
 {
 	if(!m_helper_program)
-		config_set_helper("xterm -e 'alsamixer'");
+		config_set_helper(DEFAULT_MIXERAPP);
 	if(!m_channel)
 		config_set_channel(NULL);
 	if(!m_card)
@@ -102,6 +103,7 @@ static void config_read()
 	m_hotkey_up_enabled = g_key_file_get_boolean(kf, "Hotkeys", "up_enabled", NULL);
 	m_hotkey_down_enabled = g_key_file_get_boolean(kf, "Hotkeys", "down_enabled", NULL);
 	m_hotkey_mute_enabled = g_key_file_get_boolean(kf, "Hotkeys", "mute_enabled", NULL);
+	m_use_transparent_background = g_key_file_get_boolean(kf, "StatusIcon", "use_transparent_background", NULL);
 	g_key_file_free(kf);
 
 	// Load default values for unset keys
@@ -193,6 +195,11 @@ void config_set_hotkey_mute_enabled(gboolean enabled)
 	m_hotkey_mute_enabled = enabled;
 }
 
+void config_set_use_transparent_background(gboolean active)
+{
+	m_use_transparent_background = active;
+}
+
 const gchar * config_get_helper()
 {
 	return m_helper_program;
@@ -273,6 +280,11 @@ gboolean config_get_hotkey_mute_enabled()
 	return m_hotkey_mute_enabled;
 }
 
+gboolean config_get_use_transparent_background()
+{
+	return m_use_transparent_background;
+}
+
 void config_write()
 {
 	assert(m_config_file != NULL);
@@ -286,6 +298,7 @@ void config_write()
 	g_key_file_set_boolean(kf, "Hotkeys", "up_enabled", m_hotkey_up_enabled);
 	g_key_file_set_boolean(kf, "Hotkeys", "down_enabled", m_hotkey_down_enabled);
 	g_key_file_set_boolean(kf, "Hotkeys", "mute_enabled", m_hotkey_mute_enabled);
+	g_key_file_set_boolean(kf, "StatusIcon", "use_transparent_background", m_use_transparent_background);
 	if(m_helper_program)
 		g_key_file_set_value(kf, "StatusIcon", "onclick", m_helper_program);
 	if(m_theme)
@@ -308,12 +321,13 @@ void config_write()
 	g_key_file_free(kf);
 }
 
-void config_initialize()
+void config_initialize(gchar * config_name)
 {
 	// Build config directory name
 	gchar * config_dir = g_build_filename(g_get_user_config_dir(),
 		CONFIG_DIRNAME, NULL);
-	m_config_file = g_build_filename(config_dir, CONFIG_FILENAME, NULL);
+	m_config_file = g_build_filename(config_dir,
+		config_name ? config_name : CONFIG_FILENAME, NULL);
 
 	// Make sure config directory exists
 	if(!g_file_test(config_dir, G_FILE_TEST_IS_DIR))
