@@ -25,6 +25,7 @@
 #include <assert.h>
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
+#include <glib/gi18n.h>
 #include <signal.h>
 #include <unistd.h>
 
@@ -70,6 +71,32 @@ enum HOTKEY
 #define SCALE_HIDE_DELAY 500
 #define TIMER_INTERVAL 50
 
+//##############################################################################
+// Type definitions
+//##############################################################################
+typedef struct
+{
+	GtkBuilder * builder;
+	GtkWidget * window;
+	GtkAdjustment * volume_adjustment;
+	GtkEntry * mixer_entry;
+	GtkComboBox * channel_combobox;
+	GtkListStore * channel_store;
+	GtkComboBox * theme_combobox;
+	GtkListStore * theme_store;
+	GtkListStore * hotkey_store;
+	GtkButton * close_button;
+	GtkRadioButton * mute_radiobutton;
+	GtkRadioButton * slider_radiobutton;
+	GtkRadioButton * mmb_mute_radiobutton;
+	GtkRadioButton * mmb_mixer_radiobutton;
+	GtkCheckButton * use_horizontal_slider_checkbutton;
+	GtkCheckButton * show_sound_level_checkbutton;
+	GtkCellRenderer * cra_hotkey;
+	GtkCellRendererToggle * crt_hotkey;
+	GtkCheckButton * use_transparent_background_checkbutton;
+} PreferencesGui;
+
 //##############################################################################
 // Static variables
 //##############################################################################
@@ -80,6 +107,7 @@ static GtkStatusIcon * m_status_icon = NULL;
 static GtkWidget * m_scale_window = NULL;
 static GtkWidget * m_scale = NULL;
 static gboolean m_setting_scale_value = FALSE;
+static PreferencesGui * gui = NULL;
 
 // Backend Interface
 static void (*backend_setup)(const gchar * card, const gchar * channel,
@@ -109,31 +137,6 @@ static void volume_icon_load_icons();
 static void scale_update();
 static void notification_show();
 
-//##############################################################################
-// Type definitions
-//##############################################################################
-typedef struct
-{
-	GtkBuilder * builder;
-	GtkWidget * window;
-	GtkAdjustment * volume_adjustment;
-	GtkEntry * mixer_entry;
-	GtkComboBox * channel_combobox;
-	GtkListStore * channel_store;
-	GtkComboBox * theme_combobox;
-	GtkListStore * theme_store;
-	GtkListStore * hotkey_store;
-	GtkButton * close_button;
-	GtkRadioButton * mute_radiobutton;
-	GtkRadioButton * slider_radiobutton;
-	GtkRadioButton * mmb_mute_radiobutton;
-	GtkRadioButton * mmb_mixer_radiobutton;
-	GtkCheckButton * use_horizontal_slider_checkbutton;
-	GtkCheckButton * show_sound_level_checkbutton;
-	GtkCellRenderer * cra_hotkey;
-	GtkCellRendererToggle * crt_hotkey;
-} PreferencesGui;
-
 //##############################################################################
 // Static functions
 //##############################################################################
@@ -141,22 +144,20 @@ typedef struct
 static gboolean preferences_window_delete_event(GtkWidget * widget,
 	GdkEvent * event, gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	gtk_widget_destroy(gui->window);
 	return FALSE;
 }
 
-static void preferences_window_destroy(GtkObject * object, gpointer user_data)
+static void preferences_window_destroy(GObject * object, gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	free(gui);
+	gui = NULL;
 	config_write();
 }
 
 static void preferences_close_button_clicked(GtkWidget * widget,
 	gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	gtk_widget_destroy(gui->window);
 }
 
@@ -197,7 +198,6 @@ static void preferences_show_sound_level_checkbutton_toggled(GtkCheckButton * wi
 static void preferences_theme_combobox_changed(GtkComboBox * widget,
 	gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	GtkTreeIter iter;
 
 	// Get the theme from the combobox
@@ -216,7 +216,6 @@ static void preferences_theme_combobox_changed(GtkComboBox * widget,
 static void preferences_channel_combobox_changed(GtkComboBox * widget,
 	gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	GtkTreeIter iter;
 
 	// Get the channel from the combobox
@@ -238,21 +237,18 @@ static void preferences_channel_combobox_changed(GtkComboBox * widget,
 static void preferences_volume_adjustment_changed(GtkSpinButton * spinbutton,
 	gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	config_set_stepsize((int)gtk_adjustment_get_value(gui->volume_adjustment));
 }
 
 static void preferences_mixer_entry_changed(GtkEditable * editable,
 	gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	config_set_helper(gtk_entry_get_text(gui->mixer_entry));
 }
 
 static void preferences_crt_toggled(GtkCellRendererToggle * cell_renderer,
 	gchar * path, gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	GtkTreeIter iter;
 
 	if(gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(gui->hotkey_store), &iter, path))
@@ -289,7 +285,6 @@ static void preferences_cra_accel_edited(GtkCellRendererAccel * renderer,
 	gchar * path, guint accel_key, GdkModifierType mask, guint hardware_keycode,
 	gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)user_data;
 	GtkTreeIter iter;
 	
 	if(gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(gui->hotkey_store), &iter, path))
@@ -320,11 +315,27 @@ static void preferences_cra_accel_edited(GtkCellRendererAccel * renderer,
 	}
 }
 
+static void preferences_use_transparent_background_checkbutton_toggled(GtkCheckButton * widget,
+	gpointer user_data)
+{
+	gboolean active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+	config_set_use_transparent_background(active);
+	gtk_widget_destroy(m_scale);
+	gtk_widget_destroy(m_scale_window);
+	scale_setup();
+}
+
 // Menu handlers
 static void menu_preferences_on_activate(GtkMenuItem * menuitem,
 	gpointer user_data)
 {
-	PreferencesGui * gui = (PreferencesGui*)malloc(sizeof(PreferencesGui));
+
+	if( gui ){
+		gtk_window_present(GTK_WINDOW(gui->window));
+		return;
+	}
+
+	gui = (PreferencesGui*)malloc(sizeof(PreferencesGui));
 
 	gui->builder = gtk_builder_new();
 	gtk_builder_add_from_file(gui->builder, PREFERENCES_UI_FILE, NULL);
@@ -348,6 +359,7 @@ static void menu_preferences_on_activate(GtkMenuItem * menuitem,
 	gui->show_sound_level_checkbutton = GTK_CHECK_BUTTON(getobj("show_sound_level"));
 	gui->cra_hotkey = GTK_CELL_RENDERER(getobj("cra_hotkey"));
 	gui->crt_hotkey = GTK_CELL_RENDERER_TOGGLE(getobj("crt_hotkey"));
+	gui->use_transparent_background_checkbutton = GTK_CHECK_BUTTON(getobj("use_transparent_background"));
 	#undef getobj
 
 	// Set the window icon
@@ -382,6 +394,9 @@ static void menu_preferences_on_activate(GtkMenuItem * menuitem,
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gui->show_sound_level_checkbutton),
 		config_get_show_sound_level());
 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gui->use_transparent_background_checkbutton),
+		config_get_use_transparent_background());
+
 	// Fill the channel model and combobox
 	GtkTreeIter tree_iter;
 	const GList * list_iter = backend_get_channel_names();
@@ -413,13 +428,13 @@ static void menu_preferences_on_activate(GtkMenuItem * menuitem,
 
 	// Fill the hotkey binding model
 	gtk_list_store_append(gui->hotkey_store, &tree_iter);
-	gtk_list_store_set(gui->hotkey_store, &tree_iter, 0, "Volume Up", 1,
+	gtk_list_store_set(gui->hotkey_store, &tree_iter, 0, _("Volume Up"), 1,
 		config_get_hotkey_up(), 2, (int)UP, 3, config_get_hotkey_up_enabled(), -1);
 	gtk_list_store_append(gui->hotkey_store, &tree_iter);
-	gtk_list_store_set(gui->hotkey_store, &tree_iter, 0, "Volume Down", 1,
+	gtk_list_store_set(gui->hotkey_store, &tree_iter, 0, _("Volume Down"), 1,
 		config_get_hotkey_down(), 2, (int)DOWN, 3, config_get_hotkey_down_enabled(), -1);
 	gtk_list_store_append(gui->hotkey_store, &tree_iter);
-	gtk_list_store_set(gui->hotkey_store, &tree_iter, 0, "Mute", 1,
+	gtk_list_store_set(gui->hotkey_store, &tree_iter, 0, _("Mute"), 1,
 		config_get_hotkey_mute(), 2, (int)MUTE, 3, config_get_hotkey_mute_enabled(), -1);
 
 	// Initialize widgets / connect signals
@@ -427,31 +442,33 @@ static void menu_preferences_on_activate(GtkMenuItem * menuitem,
 	gtk_adjustment_set_value(gui->volume_adjustment,
 		(gdouble)config_get_stepsize());
 	g_signal_connect(G_OBJECT(gui->window), "destroy", G_CALLBACK(
-		preferences_window_destroy), (gpointer)gui);
+		preferences_window_destroy), NULL);
 	g_signal_connect(G_OBJECT(gui->window), "delete-event", G_CALLBACK(
-		preferences_window_delete_event), (gpointer)gui);
+		preferences_window_delete_event), NULL);
 	g_signal_connect(G_OBJECT(gui->close_button), "clicked", G_CALLBACK(
-		preferences_close_button_clicked), (gpointer)gui);
+		preferences_close_button_clicked), NULL);
 	g_signal_connect(G_OBJECT(gui->channel_combobox), "changed", G_CALLBACK(
-		preferences_channel_combobox_changed), (gpointer)gui);
+		preferences_channel_combobox_changed), NULL);
 	g_signal_connect(G_OBJECT(gui->theme_combobox), "changed", G_CALLBACK(
-		preferences_theme_combobox_changed), (gpointer)gui);
+		preferences_theme_combobox_changed), NULL);
 	g_signal_connect(G_OBJECT(gui->volume_adjustment), "value-changed",
-		G_CALLBACK(preferences_volume_adjustment_changed), (gpointer)gui);
+		G_CALLBACK(preferences_volume_adjustment_changed), NULL);
 	g_signal_connect(G_OBJECT(gui->mixer_entry), "changed", G_CALLBACK(
-		preferences_mixer_entry_changed), (gpointer)gui);
+		preferences_mixer_entry_changed), NULL);
 	g_signal_connect(G_OBJECT(gui->mute_radiobutton), "toggled", G_CALLBACK(
-		preferences_mute_radiobutton_toggled), (gpointer)gui);
+		preferences_mute_radiobutton_toggled), NULL);
 	g_signal_connect(G_OBJECT(gui->mmb_mixer_radiobutton), "toggled", G_CALLBACK(
-		preferences_mmb_radiobutton_toggled), (gpointer)gui);
+		preferences_mmb_radiobutton_toggled), NULL);
 	g_signal_connect(G_OBJECT(gui->use_horizontal_slider_checkbutton), "toggled", G_CALLBACK(
-		preferences_use_horizontal_slider_checkbutton_toggled), (gpointer)gui);
+		preferences_use_horizontal_slider_checkbutton_toggled), NULL);
 	g_signal_connect(G_OBJECT(gui->show_sound_level_checkbutton), "toggled", G_CALLBACK(
-		preferences_show_sound_level_checkbutton_toggled), (gpointer)gui);
+		preferences_show_sound_level_checkbutton_toggled), NULL);
 	g_signal_connect(G_OBJECT(gui->cra_hotkey), "accel-edited", G_CALLBACK(
-		preferences_cra_accel_edited), (gpointer)gui);
+		preferences_cra_accel_edited), NULL);
 	g_signal_connect(G_OBJECT(gui->crt_hotkey), "toggled", G_CALLBACK(
-		preferences_crt_toggled), (gpointer)gui);
+		preferences_crt_toggled), NULL);
+	g_signal_connect(G_OBJECT(gui->use_transparent_background_checkbutton), "toggled", G_CALLBACK(
+		preferences_use_transparent_background_checkbutton_toggled), NULL);
 
 	gtk_widget_show_all(gui->window);
 }
@@ -507,13 +524,18 @@ static gboolean scale_timeout(gpointer data)
 	GdkRectangle icon;
 
 	gtk_window_get_position(GTK_WINDOW(m_scale_window), &window.x, &window.y);
-	gtk_window_get_size(GTK_WINDOW(m_scale_window), &window.width,
-		&window.height);
+	gtk_window_get_size(GTK_WINDOW(m_scale_window), &window.width, &window.height);
 	gtk_status_icon_get_geometry(m_status_icon, NULL, &icon, NULL);
 
+	GdkWindow *root_window;
+	GdkDeviceManager *device_manager;
+	GdkDevice *pointer;
 	gint x, y;
-	gdk_window_get_pointer(gtk_widget_get_root_window(m_scale_window),
-		&x, &y, NULL);
+
+	root_window = gtk_widget_get_root_window(m_scale_window);
+	device_manager = gdk_display_get_device_manager(gdk_window_get_display(root_window));
+	pointer = gdk_device_manager_get_client_pointer(device_manager);
+	gdk_window_get_device_position(root_window, pointer, &x, &y, NULL);
 
 	if(scale_point_in_rect(&window, x, y) || scale_point_in_rect(&icon, x, y))
 	{
@@ -534,11 +556,7 @@ static void status_icon_on_button_release(GtkStatusIcon * status_icon,
 	GdkEventButton * event, gpointer user_data)
 {
 	if(event->button == 1 && config_get_left_mouse_slider() &&
-	#if GTK_CHECK_VERSION(2, 20, 0)
 		!gtk_widget_get_visible(m_scale_window))
-	#else
-		!GTK_WIDGET_VISIBLE(m_scale_window))
-	#endif
 	{
 		gint sizex;
 		gint sizey;
@@ -618,7 +636,7 @@ static void status_icon_on_popup_menu(GtkStatusIcon * status_icon, guint button,
 {
 	GtkWidget * gtkMenu = gtk_menu_new();
 
-	GtkWidget * volcontrol = gtk_image_menu_item_new_with_label("Open Mixer");
+	GtkWidget * volcontrol = gtk_image_menu_item_new_with_label(_("Open Mixer"));
 	GtkWidget * separator1 = gtk_separator_menu_item_new();
 	GtkWidget * preferences = gtk_image_menu_item_new_from_stock(
 		"gtk-preferences", NULL);
@@ -634,12 +652,12 @@ static void status_icon_on_popup_menu(GtkStatusIcon * status_icon, guint button,
 	g_signal_connect(G_OBJECT(about), "activate",
 		G_CALLBACK(menu_about_on_activate), NULL);
 
-	gtk_menu_append(gtkMenu, volcontrol);
-	gtk_menu_append(gtkMenu, separator1);
-	gtk_menu_append(gtkMenu, preferences);
-	gtk_menu_append(gtkMenu, about);
-	gtk_menu_append(gtkMenu, separator2);
-	gtk_menu_append(gtkMenu, quit);
+	gtk_menu_shell_append(GTK_MENU_SHELL(gtkMenu), volcontrol);
+	gtk_menu_shell_append(GTK_MENU_SHELL(gtkMenu), separator1);
+	gtk_menu_shell_append(GTK_MENU_SHELL(gtkMenu), preferences);
+	gtk_menu_shell_append(GTK_MENU_SHELL(gtkMenu), about);
+	gtk_menu_shell_append(GTK_MENU_SHELL(gtkMenu), separator2);
+	gtk_menu_shell_append(GTK_MENU_SHELL(gtkMenu), quit);
 
 	gtk_widget_show_all(gtkMenu);
 
@@ -714,12 +732,8 @@ static void status_icon_update(gboolean mute, gboolean ignore_cache)
 	{
 		gchar buffer[32];
 		g_sprintf(buffer, "%s: %d%%", backend_get_channel(), volume);
-		#if GTK_CHECK_VERSION(2,16,0)
 		gtk_status_icon_set_tooltip_text(m_status_icon, buffer);
-		#else
-		gtk_status_icon_set_tooltip(m_status_icon, buffer);
-		#endif
-		
+
 		#ifdef COMPILEWITH_NOTIFY
 		notify_notification_set_hint_int32(m_notification, "value",
 			(gint)volume);
@@ -758,10 +772,10 @@ static void volume_icon_load_icons()
 	int i;
 	for(i = 0; i < ICON_COUNT; i++)
 	{
-		gchar * icon_path = g_strdup_printf(ICONS_DIR"/%s/%d.png",
+		gchar * icon_path = g_strdup_printf(ICONS_DIR "/%s/%d.png",
 			config_get_theme(), i+1);
 		if(icons_loaded && (NULL != m_icons[i]))
-			gdk_pixbuf_unref(m_icons[i]);
+			g_object_unref(m_icons[i]);
 		m_icons[i] = gdk_pixbuf_new_from_file(icon_path, NULL);
 		if(NULL == m_icons[i])
 			g_message("Failed to load '%s'", icon_path);
@@ -806,16 +820,102 @@ static void notification_show()
 	#endif
 }
 
+static void render_widget (cairo_t *cairo_context, gint width, gint height)
+{
+	cairo_set_source_rgba (cairo_context, 1.0, 1.0, 1.0, 0.0);
+	cairo_set_operator (cairo_context, CAIRO_OPERATOR_SOURCE);
+	cairo_paint (cairo_context);
+}
+
+static void update_widget (GtkWidget *widget, gint width, gint height)
+{
+	cairo_surface_t *mask;
+	cairo_region_t *mask_region;
+
+	mask = cairo_image_surface_create(CAIRO_FORMAT_A1, width, height);
+	if (cairo_surface_status(mask) == CAIRO_STATUS_SUCCESS) {
+
+		cairo_t *cairo_context = cairo_create(mask);
+		if (cairo_status(cairo_context) == CAIRO_STATUS_SUCCESS) {
+
+			render_widget(cairo_context, width, height);
+			cairo_destroy(cairo_context);
+
+			mask_region = gdk_cairo_region_create_from_surface(mask);
+
+			gtk_widget_input_shape_combine_region(widget, NULL);
+			if (!gtk_widget_is_composited(widget))
+				gtk_widget_input_shape_combine_region(widget, mask_region);
+
+			gtk_widget_shape_combine_region(widget, NULL);
+			if (!gtk_widget_is_composited(widget))
+				gtk_widget_shape_combine_region(widget, mask_region);
+
+			cairo_region_destroy(mask_region);
+		}
+
+		cairo_surface_destroy(mask);
+	}
+}
+
+static gboolean on_configure (GtkWidget *widget, GdkEventConfigure *event, gpointer user_data)
+{
+	static gint width = 0, height = 0;
+	if (width != event->width || height != event->height) {
+		width  = event->width;
+		height = event->height;
+		update_widget (widget, width, height);
+	}
+	return FALSE;
+}
+
+static gboolean on_draw (GtkWidget *widget, cairo_t *cairo_context, gpointer user_data)
+{
+	render_widget(cairo_context,
+		gtk_widget_get_allocated_width(widget),
+		gtk_widget_get_allocated_height(widget));
+	return FALSE;
+}
+
+static void on_composited_changed (GtkWidget* window, gpointer user_data)
+{
+	gtk_widget_destroy(m_scale);
+	gtk_widget_destroy(m_scale_window);
+	scale_setup();
+}
+
 static void scale_setup()
 {
+	GdkScreen *screen;
+
 	if(config_get_use_horizontal_slider())
-		m_scale = gtk_hscale_new_with_range(0.0, 100.0, 1.0);
+		m_scale = gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL, 0.0, 100.0, 1.0);
 	else
-		m_scale =  gtk_vscale_new_with_range(0.0, 100.0, 1.0);
+		m_scale = gtk_scale_new_with_range(GTK_ORIENTATION_VERTICAL, 0.0, 100.0, 1.0);
 	gtk_range_set_inverted(GTK_RANGE(m_scale), TRUE);
 	gtk_scale_set_draw_value(GTK_SCALE(m_scale), config_get_show_sound_level());
 
 	m_scale_window = gtk_window_new(GTK_WINDOW_POPUP);
+
+	screen = gtk_widget_get_screen(GTK_WIDGET(m_scale_window));
+	if (gdk_screen_is_composited(screen) && config_get_use_transparent_background()) {
+		GdkVisual *visual = gdk_screen_get_rgba_visual(screen);
+		if (visual) {
+			gtk_widget_set_visual(GTK_WIDGET(m_scale_window), visual);
+			gtk_widget_set_app_paintable(GTK_WIDGET(m_scale_window), TRUE);
+			gtk_widget_realize(GTK_WIDGET(m_scale_window));
+			gdk_window_set_background_pattern(gtk_widget_get_window(GTK_WIDGET(m_scale_window)), NULL);
+			gtk_window_set_type_hint(GTK_WINDOW(m_scale_window), GDK_WINDOW_TYPE_HINT_DOCK);
+
+			g_signal_connect(G_OBJECT(m_scale_window), "draw", G_CALLBACK(on_draw), NULL);
+			g_signal_connect(G_OBJECT(m_scale_window), "configure-event", G_CALLBACK(on_configure), NULL);
+
+			update_widget(GTK_WIDGET(m_scale_window),
+				gtk_widget_get_allocated_width(GTK_WIDGET(m_scale_window)),
+				gtk_widget_get_allocated_height(GTK_WIDGET(m_scale_window)));
+		}
+	}
+
 	gtk_window_set_decorated(GTK_WINDOW(m_scale_window), FALSE);
 	gtk_window_set_skip_pager_hint(GTK_WINDOW(m_scale_window), TRUE);
 	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(m_scale_window), TRUE);
@@ -835,6 +935,8 @@ static void scale_setup()
 
 	g_signal_connect(G_OBJECT(m_scale), "value-changed",
 		G_CALLBACK(scale_value_changed), NULL);
+	g_signal_connect(G_OBJECT(m_scale_window), "composited-changed",
+		G_CALLBACK(on_composited_changed), NULL);
 }
 
 static void hotkey_handle(const char * key, void * user_data)
@@ -864,7 +966,19 @@ static void hotkey_handle(const char * key, void * user_data)
 //##############################################################################
 int main(int argc, char * argv[])
 {
-	gtk_init(&argc, &argv);
+    bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+    textdomain(GETTEXT_PACKAGE);
+
+	// Initialize gtk with arguments
+	GError **errors = 0;
+	gchar * config_name = 0;
+	GOptionEntry options[] = {
+		{ "config", 'c', 0, G_OPTION_ARG_FILENAME, &config_name,
+			_("Alternate name to use for config file, default is volumeicon"), "name" },
+		{ NULL }
+	};
+	gtk_init_with_args(&argc, &argv, "", options, "", errors);
 	signal(SIGCHLD, SIG_IGN);
 
 	// Setup OSD Notification
@@ -907,7 +1021,7 @@ int main(int argc, char * argv[])
 	#endif
 
 	// Setup
-	config_initialize();
+	config_initialize(config_name);
 	backend_setup(config_get_card(), config_get_channel(), volume_icon_on_volume_changed);
 	m_volume = backend_get_volume();
 	m_mute = backend_get_mute();
